@@ -192,6 +192,7 @@ bool KJob::exec()
 
     start();
     if (!d->isFinished) {
+        d->m_startedWithExec = true;
         d->eventLoop->exec(QEventLoop::ExcludeUserInputEvents);
     }
     d->eventLoop = nullptr;
@@ -275,9 +276,6 @@ void KJob::setProcessedAmount(Unit unit, qulonglong amount)
     processed = amount;
 
     if (should_emit) {
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
-        Q_EMIT processedAmount(this, unit, amount);
-#endif
         Q_EMIT processedAmountChanged(this, unit, amount, QPrivateSignal{});
         if (unit == d->progressUnit) {
             Q_EMIT processedSize(this, amount);
@@ -302,9 +300,6 @@ void KJob::setTotalAmount(Unit unit, qulonglong amount)
     total = amount;
 
     if (should_emit) {
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
-        Q_EMIT totalAmount(this, unit, amount);
-#endif
         Q_EMIT totalAmountChanged(this, unit, amount, QPrivateSignal{});
         if (unit == d->progressUnit) {
             Q_EMIT totalSize(this, amount);
@@ -324,9 +319,6 @@ void KJob::setPercent(unsigned long percentage)
     Q_D(KJob);
     if (d->percentage != percentage) {
         d->percentage = percentage;
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
-        Q_EMIT percent(this, percentage);
-#endif
         Q_EMIT percentChanged(this, percentage, QPrivateSignal{});
     }
 }
@@ -340,17 +332,8 @@ void KJob::emitResult()
 
 void KJob::emitPercent(qulonglong processedAmount, qulonglong totalAmount)
 {
-    Q_D(KJob);
-    // calculate percents
-    if (totalAmount) {
-        unsigned long oldPercentage = d->percentage;
-        d->percentage = 100.0 * processedAmount / totalAmount;
-        if (d->percentage != oldPercentage) {
-#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 80)
-            Q_EMIT percent(this, d->percentage);
-#endif
-            Q_EMIT percentChanged(this, d->percentage, QPrivateSignal{});
-        }
+    if (totalAmount != 0) {
+        setPercent(100.0 * processedAmount / totalAmount);
     }
 }
 
@@ -401,4 +384,10 @@ bool KJob::isFinishedNotificationHidden() const
     return d->m_hideFinishedNotification;
 }
 
+bool KJob::isStartedWithExec() const
+{
+    Q_D(const KJob);
+    return d->m_startedWithExec;
+}
+
 #include "moc_kjob.cpp"
